[Top][All Lists]
[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Emacs-diffs] /srv/bzr/emacs/trunk r102232: landmark: you lose.
From: |
Glenn Morris |
Subject: |
[Emacs-diffs] /srv/bzr/emacs/trunk r102232: landmark: you lose. |
Date: |
Tue, 02 Nov 2010 20:35:38 -0700 |
User-agent: |
Bazaar (2.0.3) |
------------------------------------------------------------
revno: 102232
committer: Glenn Morris <address@hidden>
branch nick: trunk
timestamp: Tue 2010-11-02 20:35:38 -0700
message:
landmark: you lose.
* lisp/play/landmark.el (lm-losing-threshold): Correct spelling.
(lm-human-plays): Use new name.
modified:
lisp/ChangeLog
lisp/play/landmark.el
=== modified file 'lisp/ChangeLog'
--- a/lisp/ChangeLog 2010-11-03 03:33:24 +0000
+++ b/lisp/ChangeLog 2010-11-03 03:35:38 +0000
@@ -1,5 +1,8 @@
2010-11-03 Glenn Morris <address@hidden>
+ * play/landmark.el (lm-losing-threshold): Correct spelling.
+ (lm-human-plays): Use new name.
+
* play/gomoku.el (gomoku-loosing-threshold): Correct spelling.
(gomoku-human-plays): Use new name.
=== modified file 'lisp/play/landmark.el'
--- a/lisp/play/landmark.el 2010-10-31 14:40:01 +0000
+++ b/lisp/play/landmark.el 2010-11-03 03:35:38 +0000
@@ -282,7 +282,7 @@
;; its contents as a set, i.e. not considering the order of its elements. The
;; highest score is given to the "OOOO" qtuples because playing in such a
;; qtuple is winning the game. Just after this comes the "XXXX" qtuple because
;; not playing in it is just loosing the game, and so on. Note that a
;; "polluted" qtuple, i.e. one containing at least one X and at least one O,
;; has score zero because there is no more any point in playing in it, from
;; both an attacking and a defending point of view.
@@ -352,13 +352,13 @@
;; qtuple, thus to be a winning move. Similarly, the only way for a square to
;; have a score between XXXXscore and OOOOscore is to belong to a "XXXX"
;; qtuple. We may use these considerations to detect when a given move is
;; winning or loosing.
(defconst lm-winning-threshold
(aref lm-score-trans-table (+ 6 6 6 6)) ;; OOOOscore
"Threshold score beyond which an Emacs move is winning.")
-(defconst lm-loosing-threshold
+(defconst lm-losing-threshold
(aref lm-score-trans-table (+ 1 1 1 1)) ;; XXXXscore
"Threshold score beyond which a human move is winning.")
@@ -771,7 +771,7 @@
(t
(setq score (aref lm-score-table square))
(lm-play-move square 1)
- (cond ((and (>= score lm-loosing-threshold)
+ (cond ((and (>= score lm-losing-threshold)
;; Just testing SCORE > THRESHOLD is not enough for
;; detecting wins, it just gives an indication that
;; we confirm with LM-FIND-FILLED-QTUPLE.
[Prev in Thread] |
Current Thread |
[Next in Thread] |
- [Emacs-diffs] /srv/bzr/emacs/trunk r102232: landmark: you lose.,
Glenn Morris <=
@@ -282,7 +282,7 @@
;; highest score is given to the "OOOO" qtuples because playing in such a
;; qtuple is winning the game. Just after this comes the "XXXX" qtuple because
-;; not playing in it is just loosing the game, and so on. Note that a
+;; not playing in it is just losing the game, and so on. Note that a
;; "polluted" qtuple, i.e. one containing at least one X and at least one O,
;; has score zero because there is no more any point in playing in it, from
@@ -352,13 +352,13 @@
;; have a score between XXXXscore and OOOOscore is to belong to a "XXXX"
;; qtuple. We may use these considerations to detect when a given move is
-;; winning or loosing.
+;; winning or losing.
(defconst lm-winning-threshold
(aref lm-score-trans-table (+ 6 6 6 6)) ;; OOOOscore